Examples
########

Templates
*********

* `Objects first templates <https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/objects_first>`_ 
* `Classes first templates <https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/classes_first>`_


Snippets
********

These examples are used as tests. They show how different concepts are realized in miniworldmaker:

* `Basics and Costumes <https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/1%20Costumes%20and%20Backgrounds>`_
* `Moving <https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/2%20Movement>`_
* `Animations <https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/3%20Animations>`_
* `Physics <https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/4%20Physics>`_
* `Timer <https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/5%20Timer>`_
* `GUI <https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/6%20GUI>`_
* `Processing <https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/7%20Processing>`_
* `Events <https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples/tests/8%20Events>`_
